@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2003, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/arc.c,v 4.30 2002/01/05 02:47:58 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/arc.c,v 1.2 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_ARC_C_
@@ -2291,7 +2291,7 @@ void MakePreciseArc()
    obj_ptr = CreateArcObj(0, 0, x1, y1, x2, y2, dir, -r, -r, r*2, r*2,
          theta1*64, angle2*64, FALSE);
 
-   PlaceTopObj(obj_ptr);
+   PlaceTopObj(obj_ptr, NULL, NULL);
    SelectTopObj();
    RecordNewObjCmd();
    SetFileModified(TRUE);
