@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/attr.c,v 4.39 2003/02/25 01:17:42 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/attr.c,v 1.6 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_ATTR_C_
@@ -71,7 +71,9 @@
 #include "wb.e"
 
 int dropObsIconAttrWhenUpdate=FALSE;
+int maxAttrGroups=0;
 
+AttrGroupInfo	**gAttrGroupInfo=NULL;
 EditAttrInfo *gpEditAttrInEditorAttrInfo=NULL;
 
 static struct AttrRec *topAttr=NULL, *botAttr=NULL;
@@ -1558,6 +1560,38 @@ void GetRestrictedAttrNames(restricted_attr_obj, pppsz_restricted,
    }
 }
 
+void GetAttrGroupAttrNames(restricted_attr_obj, group_index, pppsz_restricted,
+      pn_num_restricted)
+   struct ObjRec *restricted_attr_obj;
+   int group_index, *pn_num_restricted;
+   char ***pppsz_restricted;
+{
+   char **ppsz_restricted=NULL, **attr_name_array=NULL;
+   int num_attrs_in_attr_group=0, i=0;
+
+   num_attrs_in_attr_group = gAttrGroupInfo[group_index]->num_attrs;
+   attr_name_array = gAttrGroupInfo[group_index]->attr_name;
+
+   if (pppsz_restricted != NULL) (*pppsz_restricted) = NULL;
+   if (pn_num_restricted != NULL) (*pn_num_restricted) = 0;
+
+   ppsz_restricted = (char**)malloc(num_attrs_in_attr_group*sizeof(char*));
+   if (ppsz_restricted == NULL) FailAllocMessage();
+   memset(ppsz_restricted, 0, num_attrs_in_attr_group*sizeof(char*));
+
+   for (i=0; i < num_attrs_in_attr_group; i++) {
+      int len=strlen(attr_name_array[i])+2; /* extra char for '=' */
+
+      ppsz_restricted[i] = (char*)malloc((len+1)*sizeof(char));
+      if (ppsz_restricted[i] == NULL) FailAllocMessage();
+      sprintf(ppsz_restricted[i], "%s=", attr_name_array[i]);
+   }
+   if (pppsz_restricted != NULL) (*pppsz_restricted) = ppsz_restricted;
+   if (pn_num_restricted != NULL) {
+      (*pn_num_restricted) = num_attrs_in_attr_group;
+   }
+}
+
 int IsRestrictedAttr(attr_name, ppsz_restricted, num_restricted)
    char *attr_name, **ppsz_restricted;
    int num_restricted;
@@ -1660,6 +1694,52 @@ EditAttrInfo *CreateEditAttrInfo(obj_ptr)
    return pEditAttrInfo;
 }
 
+EditAttrInfo *CreateEditAttrGroupInfo(obj_ptr)
+   struct ObjRec *obj_ptr;
+{
+   int i=0, num_attrs=maxAttrGroups, *fore_colors=NULL;
+   EditAttrInfo *pEditAttrInfo=NULL;
+   char **attr_strings=NULL, **status_strings=NULL;
+
+   if (num_attrs == 0) {
+      return NULL;
+   }
+   pEditAttrInfo = (EditAttrInfo*)malloc(sizeof(EditAttrInfo));
+   if (pEditAttrInfo == NULL) FailAllocMessage();
+   memset(pEditAttrInfo, 0, sizeof(EditAttrInfo));
+
+   /*
+    * For this function, we do not need to call HasEditAttrsInContextMenu()
+    *     because the "edit_attrs_in_context_menu=" attribute is only for the
+    *     "Edit Attribute In Editor" submenu and *not* for the
+    *     "Edit Attribute Group In Editor" submenu.
+    */
+   attr_strings = (char**)malloc(num_attrs*sizeof(char*));
+   status_strings = (char**)malloc(num_attrs*sizeof(char*));
+   fore_colors = (int*)malloc(num_attrs*sizeof(int));
+
+   if (attr_strings == NULL || status_strings == NULL || fore_colors == NULL) {
+      FailAllocMessage();
+   }
+   for (i=0; i < num_attrs; i++) {
+      attr_strings[i] = UtilStrDup(gAttrGroupInfo[i]->group_name);
+      sprintf(gszMsgBox, TgLoadCachedString(CSTID_EDIT_ATTR_GROUP_IN_EDITOR),
+            gAttrGroupInfo[i]->group_name, gAttrGroupInfo[i]->displayed_names);
+      status_strings[i] = UtilStrDup(gszMsgBox);
+
+      if (attr_strings[i] == NULL || status_strings[i] == NULL) {
+         FailAllocMessage();
+      }
+      fore_colors[i] = myFgPixel;
+   }
+   pEditAttrInfo->num_attrs = num_attrs;
+   pEditAttrInfo->attr_strings = attr_strings;
+   pEditAttrInfo->status_strings = status_strings;
+   pEditAttrInfo->fore_colors = fore_colors;
+
+   return pEditAttrInfo;
+}
+
 void MoveAttr()
 {
    struct ObjRec *obj_ptr=NULL;
@@ -2299,3 +2379,221 @@ void EditAttrs()
    fileAttrNameDspPtr = NULL;
    Msg("");
 }
+
+static
+int GetAttrNamesCount(buf)
+   char *buf;
+{
+   int count=0;
+
+   while (*buf != '\0') {
+      char *psz=NULL;
+
+      if (*buf == ':') return INVALID;
+
+      psz = strchr(buf, ':');
+      if (psz == NULL) {
+         count++;
+         break;
+      } else {
+         count++;
+         buf = (&psz[1]);
+      }
+   }
+   return count;
+}
+
+static
+void SetAttrGroupInfoDisplayedNames(pagi)
+   AttrGroupInfo *pagi;
+{
+   int i=0, total=0;
+   char *psz=NULL;
+
+   for (i=0; i < pagi->num_attrs; i++) {
+      total += strlen(pagi->attr_name[i])+1;
+   }
+   total += 1;
+
+   pagi->displayed_names = (char*)malloc(total*sizeof(char));
+   if (pagi->displayed_names == NULL) FailAllocMessage();
+   memset(pagi->displayed_names, 0, total*sizeof(char));
+
+   for (i=0, psz=pagi->displayed_names; i < pagi->num_attrs; i++) {
+      if (i == pagi->num_attrs-1) {
+         sprintf(psz, "%s", pagi->attr_name[i]);
+         psz += strlen(pagi->attr_name[i]);
+      } else {
+         sprintf(psz, "%s:", pagi->attr_name[i]);
+         psz += strlen(pagi->attr_name[i])+1;
+      }
+   }
+}
+
+static
+void FreeAttrGroupInfo(pagi)
+   AttrGroupInfo *pagi;
+{
+   UtilFree(pagi->group_name);
+   UtilFree(pagi->group_value);
+   UtilFree(pagi->displayed_names);
+   if (pagi->num_attrs > 0 && pagi->attr_name != NULL) {
+      free(pagi->attr_name);
+   }
+}
+
+static
+void CleanUpAttrGroup()
+{
+   int i=0;
+
+   if (maxAttrGroups != 0 && gAttrGroupInfo != NULL) {
+      for (i=0; i < maxAttrGroups; i++) {
+         FreeAttrGroupInfo(gAttrGroupInfo[i]);
+         free(gAttrGroupInfo[i]);
+      }
+      free(gAttrGroupInfo);
+   }
+   maxAttrGroups = 0;
+   gAttrGroupInfo = NULL;
+}
+
+void CleanUpAttr()
+{
+    CleanUpAttrGroup();
+}
+
+static
+int ParseAttrGroupXDef(group_index, xdef_line, buf)
+   int group_index;
+   char *xdef_line, *buf;
+{
+   char *psz_attr_names=strchr(buf, ':'), *psz_attr=NULL;
+   int count=0, index=0;
+
+   if (psz_attr_names == NULL) {
+      if (xdef_line == NULL) {
+         fprintf(stderr, TgLoadString(STID_INVALID_COMPILER_OPT),
+               "DEFATTRGROUP", buf);
+      } else {
+         fprintf(stderr, TgLoadString(STID_INVALID_XDEF), TOOL_NAME,
+               xdef_line, buf);
+      }
+      fprintf(stderr, "\n");
+      return FALSE;
+   }
+   *psz_attr_names++ = '\0';
+   count = GetAttrNamesCount(psz_attr_names);
+   if (count == INVALID) {
+      if (xdef_line == NULL) {
+         fprintf(stderr, TgLoadString(STID_INVALID_COMPILER_OPT),
+               "DEFATTRGROUP", buf);
+      } else {
+         fprintf(stderr, TgLoadString(STID_INVALID_XDEF), TOOL_NAME,
+               xdef_line, buf);
+      }
+      fprintf(stderr, "\n");
+      return FALSE;
+   }
+   gAttrGroupInfo[group_index]->group_name = UtilStrDup(buf);
+   if (gAttrGroupInfo[group_index]->group_name == NULL) {
+      FailAllocMessage();
+   }
+   UtilTrimBlanks(gAttrGroupInfo[group_index]->group_name);
+
+   gAttrGroupInfo[group_index]->group_value = UtilStrDup(psz_attr_names);
+   if (gAttrGroupInfo[group_index]->group_value == NULL) {
+      FailAllocMessage();
+   }
+   UtilTrimBlanks(gAttrGroupInfo[group_index]->group_value);
+
+   gAttrGroupInfo[group_index]->attr_name = (char**)malloc(
+         count*sizeof(char*));
+   if (gAttrGroupInfo[group_index]->attr_name == NULL) {
+      FailAllocMessage();
+   }
+   memset(gAttrGroupInfo[group_index]->attr_name, 0, count*sizeof(char*));
+
+   psz_attr = gAttrGroupInfo[group_index]->group_value;
+   while (*psz_attr != '\0') {
+      char *psz_colon=strchr(psz_attr, ':');
+
+      if (psz_colon != NULL) *psz_colon = '\0';
+
+      UtilTrimBlanks(psz_attr);
+      gAttrGroupInfo[group_index]->attr_name[index] = psz_attr;
+
+      index++;
+      if (psz_colon != NULL) {
+         psz_attr = ++psz_colon;
+      } else {
+         break;
+      }
+   }
+   gAttrGroupInfo[group_index]->num_attrs = count;
+   SetAttrGroupInfoDisplayedNames(gAttrGroupInfo[group_index]);
+
+   return TRUE;
+}
+
+int InitAttr()
+{
+   char *c_ptr=NULL, buf[MAXSTRING];
+   int i=0, attr_group_in_xdef=TRUE;
+
+   maxAttrGroups = 0;
+   if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"MaxAttributeGroups")) !=
+         NULL) {
+      maxAttrGroups = atoi(c_ptr);
+   }
+#ifdef _TANGRAM_II
+#ifdef DEFATTRGROUP
+   if (maxAttrGroups == 0) {
+      maxAttrGroups = 1;
+      attr_group_in_xdef = FALSE;
+   }
+#endif /* DEFATTRGROUP */
+#endif /* _TANGRAM_II */
+   if (maxAttrGroups >= 0) {
+      gAttrGroupInfo = (AttrGroupInfo**)malloc(maxAttrGroups *
+            sizeof(AttrGroupInfo*));
+      if (gAttrGroupInfo == NULL) FailAllocMessage();
+      memset(gAttrGroupInfo, 0, maxAttrGroups*sizeof(AttrGroupInfo*));
+
+      for (i=0; i < maxAttrGroups; i++) {
+         gAttrGroupInfo[i] = (AttrGroupInfo*)malloc(sizeof(AttrGroupInfo));
+         if (gAttrGroupInfo[i] == NULL) FailAllocMessage();
+         memset(gAttrGroupInfo[i], 0, sizeof(AttrGroupInfo));
+
+         if (attr_group_in_xdef) {
+            sprintf(buf, "AttributeGroup%1d", i);
+            if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,buf)) != NULL) {
+               ParseAttrGroupXDef(i, buf, c_ptr);
+            } else {
+               fprintf(stderr, TgLoadString(STID_CANNOT_GET_X_DEFAULT),
+                     TOOL_NAME, buf);
+               fprintf(stderr, "\n");
+            }
+         } else {
+#ifdef _TANGRAM_II
+#ifdef DEFATTRGROUP
+            char *tmp_buf=UtilStrDup(DEFATTRGROUP);
+
+            if (tmp_buf == NULL) FailAllocMessage();
+            if (!ParseAttrGroupXDef(i, NULL, tmp_buf)) {
+               CleanUpAttrGroup();
+            }
+            UtilFree(tmp_buf);
+#endif /* DEFATTRGROUP */
+#endif /* _TANGRAM_II */
+         }
+      }
+   } else if (maxAttrGroups == 0) {
+      /* nothing to do */
+   } else {
+      fprintf(stderr, TgLoadString(STID_INVALID_XDEF_USE_ALT_VALUE),
+            TOOL_NAME, "MaxAttributeGroups", c_ptr, 0);
+      fprintf(stderr, "\n");
+   }
+   return TRUE;
+}
