@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/auxtext.c,v 4.41 2003/08/08 05:07:23 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/auxtext.c,v 1.3 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_AUXTEXT_C_
@@ -655,6 +655,11 @@ int UpdTextBBox(ObjPtr)
 #ifdef _TGIF_DBG /* debug, do not translate */
    int saved_baseline_y=text_ptr->baseline_y;
 
+#endif /* _TGIF_DBG */
+
+   if (mainDisplay == NULL) return FALSE;
+
+#ifdef _TGIF_DBG /* debug, do not translate */
    if (PRTGIF && !cmdLineOpenDisplay) {
       fprintf(stderr, "UpdTextBBox() called in PRTGIF!\n");
    }
@@ -1964,8 +1969,9 @@ StrSegInfo *CreateStrSegFromString(buf, pOwnerStrBlock)
    pStrSeg->font = curFont;
    pStrSeg->style = curStyle;
    pStrSeg->sz_unit = GetCurSzUnit();
-   strcpy(pStrSeg->color_str, colorMenuItems[colorIndex]);
-
+   if (mainDisplay != NULL) {
+      strcpy(pStrSeg->color_str, colorMenuItems[colorIndex]);
+   }
    pStrSeg->double_byte = canvasFontDoubleByte;
    pStrSeg->double_byte_mod_bytes = canvasFontDoubleByteModBytes;
    pStrSeg->double_byte_vertical = canvasFontDoubleByteVertical;
@@ -1975,9 +1981,10 @@ StrSegInfo *CreateStrSegFromString(buf, pOwnerStrBlock)
 
    pStrSeg->asc = canvasFontAsc;
    pStrSeg->des = canvasFontDes;
-   pStrSeg->w = MyTextWidth(canvasFontPtr, pStrSeg->dyn_str.s,
-         pStrSeg->dyn_str.sz-1);
-
+   if (mainDisplay != NULL) {
+      pStrSeg->w = MyTextWidth(canvasFontPtr, pStrSeg->dyn_str.s,
+            pStrSeg->dyn_str.sz-1);
+   }
    pStrSeg->owner = pOwnerStrBlock;
 
    return pStrSeg;
