@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/choose.c,v 4.44 2003/08/05 04:36:22 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/choose.c,v 1.6 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_CHOOSE_C_
@@ -28,6 +28,7 @@
 #include "cutpaste.e"
 #include "cursor.e"
 #include "dialog.e"
+#include "drawing.e"
 #include "file.e"
 #include "font.e"
 #include "mainloop.e"
@@ -1260,7 +1261,7 @@ int DoNameBtnScroll(scroll_page, scroll_dir, pbbox, pni)
    int scroll_page, scroll_dir;
    struct BBRec *pbbox;
    struct NamesRec *pni;
-   /* returns TRUE if the done scrolling */
+   /* returns TRUE if done scrolling */
 {
    ScrollBtnCallbackInfo sbci;
 
@@ -1331,7 +1332,7 @@ void NameScrollHandler(button_ev)
    } else if (button_ev->button == Button1 && button_ev->type == ButtonPress) {
       if (button_ev->y < scrollBarW ||
             button_ev->y >= pni->scroll_area_h-scrollBarW) {
-         int which=0;
+         int which=INVALID;
          struct BBRec bbox;
 
          if (button_ev->y < scrollBarW) {
@@ -1461,6 +1462,28 @@ int NameDspHandler(button_ev)
    Time click_time;
    int checkbox_cols=0, box_offset=0, clicked_col=INVALID, check_updated=FALSE;
 
+   if (enableMouseWheel &&
+         (button_ev->button == Button4 || button_ev->button == Button5)) {
+      int which=INVALID;
+      struct BBRec bbox;
+
+      if (button_ev->button == Button4) {
+         which = SCRL_UP;
+         SetBBRec(&bbox, 0, 0, scrollBarW, scrollBarW);
+      } else if (button_ev->button == Button5) {
+         which = SCRL_DN;
+         SetBBRec(&bbox, 0, pni->scroll_area_h-scrollBarW, scrollBarW,
+               pni->scroll_area_h);
+      }
+      if (which != INVALID) {
+         DoNameBtnScroll(FALSE, which, &bbox, pni);
+         RedrawNameScrollWin();
+         RedrawDspWindow();
+      }
+      return INVALID;
+   } else if (button_ev->button != Button1) {
+      return INVALID;
+   }
    if (pni->p_check_array != NULL && pni->p_check_array->num_cols > 0) {
       checkbox_cols = pni->p_check_array->num_cols;
       box_offset = 1;
