@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/color.c,v 4.45 2003/02/25 01:17:43 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/color.c,v 1.2 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_COLOR_C_
@@ -46,6 +46,7 @@
 #include "rect.e"
 #include "select.e"
 #include "setup.e"
+#include "stk.e"
 #include "strtbl.e"
 #include "text.e"
 #include "util.e"
@@ -2004,6 +2005,7 @@ int FlushColormap()
    if (newColormapUsed) {
       struct PageRec *page_ptr=NULL;
       int saved_color_layers=FALSE;
+      struct AttrRec *attr_ptr=NULL;
 
       for (page_ptr=firstPage; page_ptr != NULL; page_ptr=page_ptr->next) {
          for (obj_ptr=page_ptr->bot; obj_ptr!=NULL; obj_ptr=obj_ptr->prev) {
@@ -2076,6 +2078,14 @@ int FlushColormap()
             }
          }
       }
+      if (tgifObj->fattr != NULL) {
+         for (attr_ptr=tgifObj->fattr; attr_ptr != NULL;
+               attr_ptr=attr_ptr->next) {
+            if (UpdatePixel(attr_ptr->obj, old_color_str)) {
+               changed = TRUE;
+            }
+         }
+      }
       RestoreStatusStrings();
       for (i=0; i < old_allocated_colors; i++) free(old_color_str[i]);
       free(old_color_str);
