@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/eps.c,v 4.38 2003/07/22 23:28:16 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/eps.c,v 1.3 2005/01/15 00:23:22 william Exp $
  */
 
 #define _INCLUDE_FROM_EPS_C_
@@ -780,7 +780,7 @@ int ConvertPsToXbm(pszPsPath, pszXbmPath, file_buf_sz)
 {
    FILE *pFile=NULL, *pPipe=NULL;
    char *pszCmd=NULL, szBuf[MAXSTRING];
-   int bytes_read=0;
+   int bytes_read=0, watch_cursor=watchCursorOnMainWindow;
 
    if (MkTempFile(pszXbmPath, file_buf_sz, tmpDir, TOOL_NAME) == NULL) {
       return FALSE;
@@ -811,6 +811,10 @@ int ConvertPsToXbm(pszPsPath, pszXbmPath, file_buf_sz)
       unlink(pszXbmPath);
       return FALSE;
    }
+   if (!watch_cursor) {
+      SetWatchCursor(drawWindow);
+      SetWatchCursor(mainWindow);
+   }
    writeFileFailed = FALSE;
    while ((bytes_read=fread(szBuf, sizeof(char), sizeof(szBuf), pPipe)) > 0) {
       if ((int)fwrite(szBuf, sizeof(char), bytes_read, pFile) <= 0) {
@@ -819,6 +823,10 @@ int ConvertPsToXbm(pszPsPath, pszXbmPath, file_buf_sz)
       }
    }
    pclose(pPipe);
+   if (!watch_cursor) {
+      SetDefaultCursor(mainWindow);
+      ShowCursor();
+   }
    SetStringStatus(TgLoadCachedString(CSTID_DOTS_DONE));
    free(pszCmd);
    fclose(pFile);
