@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/mainloop.c,v 4.117 2003/08/08 05:07:24 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/mainloop.c,v 1.7 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MAINLOOP_C_
@@ -43,6 +43,7 @@
 #endif /* USE_XT_INITIALIZE */
 
 #include "animate.e"
+#include "attr.e"
 #include "auxtext.e"
 #include "chat.e"
 #include "choice.e"
@@ -130,6 +131,8 @@ int	cmdLineVersion=FALSE;
 int	cmdLineNoModeWindow=FALSE;
 int	cmdLineNoChatWindow=FALSE;
 
+KeyOrBtnEvInfo	lastKeyOrBtnEvInfo;
+
 int			numExtraWins=0;
 struct WinInfoRec	*extraWinInfo=NULL;
 
@@ -201,16 +204,25 @@ void CleanUpExtraWinInfo()
    extraWinInfo = NULL;
 }
 
+static
+void InitLastKeyOrBtnEvInfo()
+{
+   memset(&lastKeyOrBtnEvInfo, 0, sizeof(KeyOrBtnEvInfo));
+}
+
 void CleanUpTalkToSelfFiledes()
 {
-   if (talkToSelfFiledes[0] != (-1)) close(talkToSelfFiledes[0]);
-   if (talkToSelfFiledes[1] != (-1)) close(talkToSelfFiledes[1]);
-
+   if (talkToSelfFiledesInitialized) {
+       if (talkToSelfFiledes[0] != (-1)) close(talkToSelfFiledes[0]);
+       if (talkToSelfFiledes[1] != (-1)) close(talkToSelfFiledes[1]);
+   }
+   talkToSelfFiledesInitialized = FALSE;
    talkToSelfFiledes[0] = talkToSelfFiledes[1] = (-1);
 }
 
 int InitTalkToSelfFiledes()
 {
+   talkToSelfFiledesInitialized = FALSE;
    talkToSelfFiledes[0] = talkToSelfFiledes[1] = (-1);
 
    if (pipe(talkToSelfFiledes) != 0) {
@@ -218,6 +230,8 @@ int InitTalkToSelfFiledes()
       fprintf(stderr, "%s\n", gszMsgBox);
       return FALSE;
    }
+   talkToSelfFiledesInitialized = TRUE;
+
    return TRUE;
 }
 
@@ -378,6 +392,7 @@ void CleanUp()
    CleanUpRecentFiles();
    CleanUpMeasureTooltip();
    CleanUpSpecial();
+   CleanUpAttr();
    CleanUpTalkToSelfFiledes();
    CleanUpTidget();
 
@@ -410,11 +425,20 @@ void ExposeEventHandler(input, recursive)
       while (XCheckWindowEvent(mainDisplay, choiceWindow, ExposureMask, &ev)) ;
       RedrawChoiceWindow();
    } else if (input->xany.window == drawWindow) {
+#ifdef ICCCM_TEST
+static int n=0;
+#endif /* ICCCM_TEST */
       while (XCheckWindowEvent(mainDisplay, drawWindow, ExposureMask, &ev)) ;
       if (topSel != NULL || curChoice==VERTEXMODE || SomethingDirty() ||
             showCrossHair) {
+#ifdef ICCCM_TEST
+fprintf(stderr, "[%1d] ExposeEventHandler(A)\n", n++);
+#endif /* ICCCM_TEST */
          ClearAndRedrawDrawWindow();
       } else {
+#ifdef ICCCM_TEST
+fprintf(stderr, "[%1d] ExposeEventHandler(B)\n", n++);
+#endif /* ICCCM_TEST */
          RedrawDrawWindow(botObj);
          RedrawCurText();
       }
@@ -533,8 +557,12 @@ int GzipFile(fname, gzipped_fname)
       fclose(out_fp);
       rc = FALSE;
    } else {
-      int bytes_read=0;
+      int bytes_read=0, watch_cursor=watchCursorOnMainWindow;
 
+      if (!watch_cursor) {
+         SetWatchCursor(drawWindow);
+         SetWatchCursor(mainWindow);
+      }
       writeFileFailed = FALSE;
       while ((bytes_read=fread(gszMsgBox, sizeof(char), sizeof(gszMsgBox),
             pfp)) > 0) {
@@ -544,6 +572,10 @@ int GzipFile(fname, gzipped_fname)
          }
       }
       pclose(pfp);
+      if (!watch_cursor) {
+         SetDefaultCursor(mainWindow);
+         ShowCursor();
+      }
       fclose(out_fp);
       if (writeFileFailed) {
          FailToWriteFileMessage(gzipped_fname);
@@ -609,8 +641,12 @@ char *GunzipFileIntoTemp(gzipped_fname)
       unlink(tmp_fname);
       tmp_fname = NULL;
    } else {
-      int bytes_read=0;
+      int bytes_read=0, watch_cursor=watchCursorOnMainWindow;
 
+      if (!watch_cursor) {
+         SetWatchCursor(drawWindow);
+         SetWatchCursor(mainWindow);
+      }
       writeFileFailed = FALSE;
       while ((bytes_read=fread(gszMsgBox, sizeof(char), sizeof(gszMsgBox),
             pfp)) > 0) {
@@ -620,6 +656,10 @@ char *GunzipFileIntoTemp(gzipped_fname)
          }
       }
       pclose(pfp);
+      if (!watch_cursor) {
+         SetDefaultCursor(mainWindow);
+         ShowCursor();
+      }
       fclose(out_fp);
       if (writeFileFailed) {
          FailToWriteFileMessage(tmp_fname);
@@ -1173,9 +1213,11 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
 
    Setup();
    InitExtraWinInfo();
+   InitLastKeyOrBtnEvInfo();
    quitDraw = FALSE;
    prTgifFoundColorInfo = FALSE;
 
+   InitWhiteBoard();
    if (pszFile == NULL) {
       /* Only gets here if PRTGIF of UrlDump() */
       DelAllPages();
@@ -1183,7 +1225,6 @@ int JustInit(pszFile, pnNeedToCheckAutoExec)
       InitPage();
       return TRUE;
    }
-   InitWhiteBoard();
    initializingMain = TRUE;
 
    if (gstWBInfo.do_whiteboard) {
@@ -1436,6 +1477,13 @@ int TryProcessAnXEvent(pnNeedToCheckAutoExec)
       return 0;
    }
 
+   /* set the lastKeyOrBtnEvInfo */
+   if (input.type == KeyPress) {
+      SetLastKeyEvInfo(&input.xkey);
+   } else if (input.type == ButtonPress) {
+      SetLastBtnEvInfo(&input.xbutton);
+   }
+
    if (input.type == FocusIn) {
       if (curChoice == DRAWTEXT && textCursorShown) {
          tgIMFocusIn(mainDisplay, input.xany.window);
@@ -1999,3 +2047,32 @@ void UpdAttrVal(ObjId, AttrName, AttrColor, AttrVal, ReturnStr)
       }
    }
 }
+
+void SetLastKeyEvInfo(key_ev)
+    XKeyEvent *key_ev;
+{
+   lastKeyOrBtnEvInfo.type = key_ev->type;
+   lastKeyOrBtnEvInfo.send_event = key_ev->send_event;
+   lastKeyOrBtnEvInfo.display = key_ev->display;
+   lastKeyOrBtnEvInfo.window = key_ev->window;
+   memcpy(&lastKeyOrBtnEvInfo.time, &key_ev->time, sizeof(Time));
+   lastKeyOrBtnEvInfo.x = key_ev->x;
+   lastKeyOrBtnEvInfo.y = key_ev->y;
+   lastKeyOrBtnEvInfo.keycode_or_button = key_ev->keycode;
+   lastKeyOrBtnEvInfo.state = key_ev->state;
+}
+
+void SetLastBtnEvInfo(button_ev)
+    XButtonEvent *button_ev;
+{
+   lastKeyOrBtnEvInfo.type = button_ev->type;
+   lastKeyOrBtnEvInfo.send_event = button_ev->send_event;
+   lastKeyOrBtnEvInfo.display = button_ev->display;
+   lastKeyOrBtnEvInfo.window = button_ev->window;
+   memcpy(&lastKeyOrBtnEvInfo.time, &button_ev->time, sizeof(Time));
+   lastKeyOrBtnEvInfo.x = button_ev->x;
+   lastKeyOrBtnEvInfo.y = button_ev->y;
+   lastKeyOrBtnEvInfo.keycode_or_button = button_ev->button;
+   lastKeyOrBtnEvInfo.state = button_ev->state;
+}
+
