@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/menuinfo.c,v 4.119 2003/08/16 19:38:52 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.3 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -1568,6 +1568,9 @@ TgMenuInfo helpMenuInfo={ TGMUTYPE_TEXT, helpMenuItemInfo,
 TgMenuInfo editAttrInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
                                       CreateEditAttrInEditorMenu };
 
+TgMenuInfo editAttrGroupInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
+                                           CreateEditAttrGroupInEditorMenu };
+
 TgMenuInfo getPropertyMenuInfo={ TGMUTYPE_TEXT, NULL, CreateGetPropertyMenu };
 
 TgMenuInfo peekDimensionMenuInfo={ TGMUTYPE_TEXT, NULL,
@@ -1592,6 +1595,9 @@ static TgMenuItemInfo baseContextMenuItemInfo[] = {
    { N_("Edit Attribute In Editor"), TGMUITEM_SUBMENU,
      N_("Edit attribute in editor submenu >>>"), &editAttrInEditorMenuInfo,
      INVALID },
+   { N_("Edit Attribute Group In Editor"), TGMUITEM_SUBMENU,
+     N_("Edit a group of attributes in editor submenu >>>"),
+     &editAttrGroupInEditorMenuInfo, INVALID },
    { N_("Get Property"), TGMUITEM_SUBMENU,
      N_("Get property submenu >>>"), &getPropertyMenuInfo, INVALID },
    { N_("Peek Dimension"), TGMUITEM_SUBMENU,
