@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/menuinfo.c,v 4.119 2003/08/16 19:38:52 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.3 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -1555,6 +1555,9 @@ TgMenuInfo helpMenuInfo={ TGMUTYPE_TEXT, helpMenuItemInfo,
 TgMenuInfo editAttrInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
                                       CreateEditAttrInEditorMenu };
 
+TgMenuInfo editAttrGroupInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
+                                           CreateEditAttrGroupInEditorMenu };
+
 TgMenuInfo getPropertyMenuInfo={ TGMUTYPE_TEXT, NULL, CreateGetPropertyMenu };
 
 TgMenuInfo peekDimensionMenuInfo={ TGMUTYPE_TEXT, NULL,
@@ -1579,6 +1582,9 @@ static TgMenuItemInfo baseContextMenuItemInfo[] = {
    { N_("Edit Attribute In Editor"), TGMUITEM_SUBMENU,
      N_("Edit attribute in editor submenu >>>"), &editAttrInEditorMenuInfo,
      INVALID },
+   { N_("Edit Attribute Group In Editor"), TGMUITEM_SUBMENU,
+     N_("Edit a group of attributes in editor submenu >>>"),
+     &editAttrGroupInEditorMenuInfo, INVALID },
    { N_("Get Property"), TGMUITEM_SUBMENU,
      N_("Get property submenu >>>"), &getPropertyMenuInfo, INVALID },
    { N_("Peek Dimension"), TGMUITEM_SUBMENU,
