@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/msg.c,v 4.80 2003/08/16 19:38:52 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/msg.c,v 1.10 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_MSG_C_
@@ -59,6 +59,7 @@
 #include "remote.e"
 #include "setup.e"
 #include "strtbl.e"
+#include "tangram2.e"
 #include "text.e"
 #include "util.e"
 #include "version.e"
@@ -75,6 +76,8 @@ char	progName[MAXPATHLENGTH+1];
 char	fatalMsgBuf1[MAXSTRING<<1];
 char	fatalMsgBuf2[MAXSTRING<<1];
 
+int	cmdLineParentWindowID=0;
+
 struct MsgRec {
    char			* s;
    struct MsgRec	* next, * prev;
@@ -1466,6 +1469,30 @@ void GetTgifVersionAndPatchLevel(buf, buf_sz)
             TGIF_DISTR_VER);
    }
 #endif /* TGIF_DISTR_VER */
+#if defined(_TANGRAM_II) || defined(_TGIF_WB2)
+   {
+#ifdef _TANGRAM_II
+      int tangram2=TRUE;
+#else /* ~_TANGRAM_II */
+      int tangram2=FALSE;
+#endif /* _TANGRAM_II */
+#ifdef _TGIF_WB2
+      int tgwb2=TRUE;
+#else /* ~_TGIF_WB2 */
+      int tgwb2=FALSE;
+#endif /* _TGIF_WB2 */
+      if (tangram2 && tgwb2) {
+         sprintf(&buf1[strlen(buf1)], TgLoadString(STID_TGIF_FLAGS),
+               "_TANGRAM_II, _TGIF_WB2");
+      } else if (tangram2) {
+         sprintf(&buf1[strlen(buf1)], TgLoadString(STID_TGIF_FLAGS),
+               "_TANGRAM_II");
+      } else if (tgwb2) {
+         sprintf(&buf1[strlen(buf1)], TgLoadString(STID_TGIF_FLAGS),
+               "_TGIF_WB2");
+      }
+   }
+#endif /* defined(_TANGRAM_II) || defined(_TGIF_WB2) */
    UtilStrCpyN(buf, buf_sz, buf1);
 }
 
@@ -1497,16 +1524,24 @@ void Usage(tool_name)
    fprintf(stdout, "\t[-listdontreencode] \\\n");
    fprintf(stdout, "\t[-version | --version] \\\n");
    fprintf(stdout, "\t[-nomode] \\\n");
+#if defined(_TANGRAM_II) || defined(_TGIF_WB2)
+   fprintf(stdout, "\t[-parent <parent_window_id>] \\\n");
+#endif /* defined(_TANGRAM_II) || defined(_TGIF_WB2) */
+#ifdef _TANGRAM_II
+   fprintf(stdout, "\t[-tg2genparse=\"<string>\"] \\\n");
+#endif /* _TANGRAM_II */
    fprintf(stdout, "\t[{<file>[.%s] | -merge <file1>[.%s] <file2>[.%s] ...}]\n",
          OBJ_FILE_EXT, OBJ_FILE_EXT, OBJ_FILE_EXT);
    fprintf(stdout, "or:\n");
    fprintf(stdout, "\t%s -print \\\n", tool_name);
    fprintf(stdout, "\t[-display displayname] \\\n");
-   fprintf(stdout, "\t[-stdout] \\\n");
    fprintf(stdout, "\t[-eps | -p | -epsi | -tiffepsi] \\\n");
    fprintf(stdout, "\t[-ps | -f] \\\n");
    fprintf(stdout, "\t[-text] \\\n");
-   fprintf(stdout, "\t[-gif | -xpm | -xbm | -html] \\\n");
+   fprintf(stdout, "\t[-gif | -png | -jpeg | -ppm | -pbm | -xpm | -xbm | -html] \\\n");
+   fprintf(stdout, "\t[-pdf] \\\n");
+   fprintf(stdout, "\t[-netlist] \\\n");
+   fprintf(stdout, "\t[-stdout] \\\n");
    fprintf(stdout, "\t[-raw[+h[eaderonly]]] \\\n");
    fprintf(stdout, "\t[-dosepsfilter [-previewonly]] \\\n");
    fprintf(stdout, "\t[-status] \\\n");
@@ -1516,7 +1551,7 @@ void Usage(tool_name)
    fprintf(stdout,
          "\t[-dontreencode=\"<%s>:<%s>:...\" | -listdontreencode] \\\n",
          "fontfamily", "fontfamily");
-   fprintf(stdout, "\t[-version | --version] \\\n");
+   fprintf(stdout, "\t[-version | --version | -justversion] \\\n");
    fprintf(stdout, "\t[-pdfspd | -pdfspd=true | -pdfspd=false] \\\n");
    fprintf(stdout, "\t[-producedby=\"<string>\"] \\\n");
    fprintf(stdout, "\t[-page <number>] \\\n");
@@ -1546,6 +1581,8 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
    char **saved_argv=argv;
 
    *cmdLineTmpFileModeStr = '\0';
+   *cmdLineGenParser = '\0';
+   *cmdLineFileToExec = '\0';
    cmdLineOneFilePerPage = FALSE;
    *outputDir = '\0';
    for (argc--, argv++; argc > 0; argc--, argv++) {
@@ -1553,6 +1590,15 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
          if (strcmp(*argv, "-version") == 0 ||
                strcmp(*argv, "--version") == 0) {
             show_copyright = TRUE;
+         } else if (strcmp(*argv, "-justversion") == 0) {
+            char buf[MAXSTRING];
+
+            GetTgifVersionAndPatchLevel(buf, sizeof(buf));
+            fprintf(stderr, "%s\n", buf);
+            fprintf(stderr, "%s (%s)\n\n", copyrightString, authorEmailString);
+            fflush(stderr);
+
+            return INVALID;
          }
       }
    }
@@ -1833,6 +1879,15 @@ int ProcessPrTgifOptions(argc, argv, from_prtgif)
             if (*cmdLineProducedBy != '\0') {
                UtilRemoveQuotes(cmdLineProducedBy);
             }
+#ifdef _TANGRAM_II
+         } else if (strncmp(*argv, "-tg2genparser=", 14) == 0) {
+            UtilStrCpyN(cmdLineGenParser, sizeof(cmdLineGenParser),
+                  &(*argv)[14]);
+            UtilTrimBlanks(cmdLineGenParser);
+            if (*cmdLineGenParser != '\0') {
+               UtilRemoveQuotes(cmdLineGenParser);
+            }
+#endif /* _TANGRAM_II */
          } else if (strcmp(*argv, "-parse_html") == 0) {
             cmdLineParseHtml = TRUE;
             /* cmdLineDumpURL will be reset in UrlDump() */
@@ -1923,6 +1978,7 @@ int ProcessTgifOptions(argc, argv, file_name, name_sz)
 
    *file_name = '\0';
    *cmdLineTmpFileModeStr = '\0';
+   *cmdLineGenParser = '\0';
    *cmdLineFileToExec = '\0';
    cmdLineMergeArgv = NULL;
    for (i=1; i < argc; i++) {
@@ -1934,6 +1990,30 @@ int ProcessTgifOptions(argc, argv, file_name, name_sz)
          if ((displayName=UtilStrDup(argv[i])) == NULL) FailAllocMessage();
       } else if (strcmp(argv[i], "-bw") == 0) {
          cmdLineBW = TRUE;
+#if defined(_TANGRAM_II) || defined(_TGIF_WB2)
+      } else if (strcmp(argv[i], "-parent") == 0) {
+         if (++i == argc) {
+            fprintf(stderr, TgLoadString(STID_MISSING_ARG_FOR_CMDLINE_OPT),
+                  "-parent");
+            fprintf(stderr, "\n");
+            Usage(progName);
+         }
+         if (strncmp(argv[i], "0x", 2) == 0) {
+            if (sscanf(&(argv[i])[2], "%x", &cmdLineParentWindowID) != 1) {
+               fprintf(stderr, TgLoadString(STID_FAIL_TO_PARSE_FOR_A_VAL),
+                     argv[i]);
+               fprintf(stderr, "\n");
+               Usage(progName);
+            }
+         } else {
+            if (sscanf(argv[i], "%d", &cmdLineParentWindowID) != 1) {
+               fprintf(stderr, TgLoadString(STID_FAIL_TO_PARSE_FOR_A_VAL),
+                     argv[i]);
+               fprintf(stderr, "\n");
+               Usage(progName);
+            }
+         }
+#endif /* defined(_TANGRAM_II) || defined(_TGIF_WB2) */
       } else if (strcmp(argv[i], "-reqcolor") == 0) {
          cmdLineRequestedColor = TRUE;
       } else if (strcmp(argv[i], "-rv") == 0) {
