@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/names.c,v 4.52 2003/02/25 01:17:46 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/names.c,v 1.3 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_NAMES_C_
@@ -691,7 +691,7 @@ void InitNames()
 {
    char *c_ptr=NULL;
 
-   InitNamesInfo();
+   if (mainDisplay != NULL) InitNamesInfo();
 
    ignoreDirectoryFlag = FALSE;
 
@@ -706,6 +706,8 @@ void InitNames()
    strcpy(curLocalDir, bootDir);
    strcpy(curImportDir, bootDir);
 
+   if (mainDisplay == NULL) return;
+
    if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "DoubleClickInterval")) !=
          NULL) {
       doubleClickInterval = atoi(c_ptr);
