@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2003, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/navigate.c,v 4.40 2002/03/24 21:18:32 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/navigate.c,v 1.3 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_NAVIGATE_C_
@@ -90,7 +90,12 @@ static int maxURLCache=(-1), curURLCache=0;
 
 static int lineWidthIndexInSlideShow=4;
 static int makeUnsavableInSlideShow=FALSE;
+static int ignoreSlideShowOffsetsInFile=TRUE;
+static int hideWindowsInSlideShow=TRUE;
 
+static int savedSlideShowXOffset=0;
+static int savedSlideShowYOffset=0;
+static int savedSlideShowOffsets=FALSE;
 
 int ParseXYSpec(spec, pnx, pny)
    char *spec;
@@ -279,6 +284,10 @@ void CleanUpNavigate()
 
    CleanUpURLCache();
    CleanUpSlideShowInfo();
+
+   savedSlideShowXOffset = 0;
+   savedSlideShowYOffset = 0;
+   savedSlideShowOffsets = FALSE;
 }
 
 void InitNavigate()
@@ -313,6 +322,10 @@ void InitNavigate()
       UtilTrimBlanks(spec);
       if (ParseXYSpec(spec, &slideShowXOffset, &slideShowYOffset)) {
          slideShowInfoValid = TRUE;
+
+         savedSlideShowXOffset = slideShowXOffset;
+         savedSlideShowYOffset = slideShowYOffset;
+         savedSlideShowOffsets = TRUE;
       } else {
          fprintf(stderr, TgLoadString(STID_INVALID_XDEF_USE_ALT_STR),
                TOOL_NAME, "SlideShowWindowOffsets", spec, "0,0");
@@ -342,6 +355,18 @@ void InitNavigate()
          NULL && UtilStrICmp(c_ptr, "true") == 0) {
       makeUnsavableInSlideShow = TRUE;
    }
+   ignoreSlideShowOffsetsInFile = TRUE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
+         "IgnoreSlideShowOffsetsInFile")) != NULL &&
+         UtilStrICmp(c_ptr, "false") == 0) {
+      ignoreSlideShowOffsetsInFile = FALSE;
+   }
+   hideWindowsInSlideShow = TRUE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
+         "HideWindowsInSlideShow")) != NULL &&
+         UtilStrICmp(c_ptr, "false") == 0) {
+      hideWindowsInSlideShow = FALSE;
+   }
 }
 
 static
@@ -1257,6 +1282,74 @@ struct SlideShowInfoRec {
 };
 static struct SlideShowInfoRec gstSlideShow;
 
+static
+void HideAllWindowsForSlideShow()
+{
+   int i=0;
+
+   if (canvasWindowOnly || !hideWindowsInSlideShow) return;
+
+   XUnmapWindow(mainDisplay, titleWindow);
+   if (menubarWindow != None) XUnmapWindow(mainDisplay, menubarWindow);
+   if (!noChoiceWindow) XUnmapWindow(mainDisplay, msgWindow);
+   if (!noChoiceWindow) XUnmapWindow(mainDisplay, choiceWindow);
+
+   XUnmapWindow(mainDisplay, hRuleWindow);
+   XUnmapWindow(mainDisplay, vRuleWindow);
+
+   XUnmapWindow(mainDisplay, colorWindow);
+   XUnmapWindow(mainDisplay, colorDummyWindow);
+   XUnmapWindow(mainDisplay, vSBarWindow);
+   XUnmapWindow(mainDisplay, pageWindow);
+   XUnmapWindow(mainDisplay, pageDummyWindow);
+   XUnmapWindow(mainDisplay, hSBarWindow);
+   XUnmapWindow(mainDisplay, dummyWindow1);
+   XUnmapWindow(mainDisplay, dummyWindow2);
+   if (!noChatWindow) XUnmapWindow(mainDisplay, chatWindow);
+   if (!noStatusWindow) {
+      XUnmapWindow(mainDisplay, userRedrawWindow);
+      XUnmapWindow(mainDisplay, statusWindow);
+      for (i=0; i < MAX_STATUS_BTNS; i++) {
+         XUnmapWindow(mainDisplay, statusSubWindow[i]);
+      }
+   }
+   if (!noModeWindow) XUnmapWindow(mainDisplay, modeWindow);
+}
+
+static
+void ShowAllWindowsForSlideShow()
+{
+   int i=0;
+
+   if (canvasWindowOnly || !hideWindowsInSlideShow) return;
+
+   XMapWindow(mainDisplay, titleWindow);
+   if (menubarWindow != None) XMapWindow(mainDisplay, menubarWindow);
+   if (!noChoiceWindow) XMapWindow(mainDisplay, msgWindow);
+   if (!noChoiceWindow) XMapWindow(mainDisplay, choiceWindow);
+
+   XMapWindow(mainDisplay, hRuleWindow);
+   XMapWindow(mainDisplay, vRuleWindow);
+
+   XMapWindow(mainDisplay, colorWindow);
+   XMapWindow(mainDisplay, colorDummyWindow);
+   XMapWindow(mainDisplay, vSBarWindow);
+   XMapWindow(mainDisplay, pageWindow);
+   XMapWindow(mainDisplay, pageDummyWindow);
+   XMapWindow(mainDisplay, hSBarWindow);
+   XMapWindow(mainDisplay, dummyWindow1);
+   XMapWindow(mainDisplay, dummyWindow2);
+   if (!noChatWindow) XMapWindow(mainDisplay, chatWindow);
+   if (!noStatusWindow) {
+      XMapWindow(mainDisplay, userRedrawWindow);
+      XMapWindow(mainDisplay, statusWindow);
+      for (i=0; i < MAX_STATUS_BTNS; i++) {
+         XMapWindow(mainDisplay, statusSubWindow[i]);
+      }
+   }
+   if (!noModeWindow) XMapWindow(mainDisplay, modeWindow);
+}
+
 static
 void StartSlideShow()
 {
@@ -1293,8 +1386,11 @@ void StartSlideShow()
    }
    FixPageNumbersForSlideShow();
    ClearObjCachesInAllPages();
+   HideAllWindowsForSlideShow();
    HidePopupMenusForSlideShow();
 
+   RecordWBSlideShow(TRUE);
+
    if (exec_attr != NULL) {
       DoExecLoop(NULL, exec_attr);
    }
@@ -1305,6 +1401,9 @@ void EndSlideShow()
 {
    XSetWindowBackground(mainDisplay, mainWindow, myBgPixel);
 
+   RecordWBSlideShow(FALSE);
+
+   ShowAllWindowsForSlideShow();
    ShowPopupMenusForSlideShow();
    ClearObjCachesInAllPages();
    if (gstSlideShow.saved_in_hyperspace != inHyperSpace) {
@@ -1328,6 +1427,7 @@ void EndSlideShow()
    MakeQuiescent();
 }
 
+static
 void ToggleSlideShow()
 {
    int need_to_restore_cur_choice=FALSE;
@@ -1384,6 +1484,16 @@ void ToggleSlideShow()
    if (need_to_restore_cur_choice) SetCurChoice(curChoiceBeforeMakeQuiescent);
 }
 
+void EnterSlideShow()
+{
+   if (!inSlideShow) ToggleSlideShow();
+}
+
+void LeaveSlideShow()
+{
+   if (inSlideShow) ToggleSlideShow();
+}
+
 void SetSlideShowBorderColor()
 {
    char spec[MAXSTRING];
@@ -1434,6 +1544,10 @@ void SetSlideShowWindowOffsets()
       sprintf(gszMsgBox, TgLoadString(STID_SLIDE_WIN_XY_OFFSETS_SET_TO),
             slideShowXOffset, slideShowYOffset);
       Msg(gszMsgBox);
+
+      savedSlideShowXOffset = slideShowXOffset;
+      savedSlideShowYOffset = slideShowYOffset;
+      savedSlideShowOffsets = TRUE;
    }
    slideShowInfoValid = TRUE;
 }
@@ -1587,9 +1701,13 @@ int ReadSlideShowInfo(buf)
          slideShowBorderColor = UtilStrDup(color_str);
          if (slideShowBorderColor == NULL) FailAllocMessage();
       }
-      slideShowXOffset = x;
-      slideShowYOffset = y;
-
+      if (!ignoreSlideShowOffsetsInFile) {
+         slideShowXOffset = x;
+         slideShowYOffset = y;
+      } else if (savedSlideShowOffsets) {
+         slideShowXOffset = savedSlideShowXOffset;
+         slideShowYOffset = savedSlideShowYOffset;
+      }
       slideShowInfoValid = TRUE;
    }
    return TRUE;
