@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/navigate.c,v 4.45 2003/02/25 01:17:47 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/navigate.c,v 1.3 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_NAVIGATE_C_
@@ -104,6 +104,7 @@ static int maxURLCache=(-1), curURLCache=0;
 static int lineWidthIndexInSlideShow=4;
 static int makeUnsavableInSlideShow=FALSE;
 static int ignoreSlideShowOffsetsInFile=TRUE;
+static int hideWindowsInSlideShow=TRUE;
 
 static int savedSlideShowXOffset=0;
 static int savedSlideShowYOffset=0;
@@ -373,6 +374,12 @@ void InitNavigate()
          UtilStrICmp(c_ptr, "false") == 0) {
       ignoreSlideShowOffsetsInFile = FALSE;
    }
+   hideWindowsInSlideShow = TRUE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
+         "HideWindowsInSlideShow")) != NULL &&
+         UtilStrICmp(c_ptr, "false") == 0) {
+      hideWindowsInSlideShow = FALSE;
+   }
 }
 
 static
@@ -1288,6 +1295,74 @@ struct SlideShowInfoRec {
 };
 static struct SlideShowInfoRec gstSlideShow;
 
+static
+void HideAllWindowsForSlideShow()
+{
+   int i=0;
+
+   if (canvasWindowOnly || !hideWindowsInSlideShow) return;
+
+   XUnmapWindow(mainDisplay, titleWindow);
+   if (menubarWindow != None) XUnmapWindow(mainDisplay, menubarWindow);
+   if (!noChoiceWindow) XUnmapWindow(mainDisplay, msgWindow);
+   if (!noChoiceWindow) XUnmapWindow(mainDisplay, choiceWindow);
+
+   XUnmapWindow(mainDisplay, hRuleWindow);
+   XUnmapWindow(mainDisplay, vRuleWindow);
+
+   XUnmapWindow(mainDisplay, colorWindow);
+   XUnmapWindow(mainDisplay, colorDummyWindow);
+   XUnmapWindow(mainDisplay, vSBarWindow);
+   XUnmapWindow(mainDisplay, pageWindow);
+   XUnmapWindow(mainDisplay, pageDummyWindow);
+   XUnmapWindow(mainDisplay, hSBarWindow);
+   XUnmapWindow(mainDisplay, dummyWindow1);
+   XUnmapWindow(mainDisplay, dummyWindow2);
+   if (!noChatWindow) XUnmapWindow(mainDisplay, chatWindow);
+   if (!noStatusWindow) {
+      XUnmapWindow(mainDisplay, userRedrawWindow);
+      XUnmapWindow(mainDisplay, statusWindow);
+      for (i=0; i < MAX_STATUS_BTNS; i++) {
+         XUnmapWindow(mainDisplay, statusSubWindow[i]);
+      }
+   }
+   if (!noModeWindow) XUnmapWindow(mainDisplay, modeWindow);
+}
+
+static
+void ShowAllWindowsForSlideShow()
+{
+   int i=0;
+
+   if (canvasWindowOnly || !hideWindowsInSlideShow) return;
+
+   XMapWindow(mainDisplay, titleWindow);
+   if (menubarWindow != None) XMapWindow(mainDisplay, menubarWindow);
+   if (!noChoiceWindow) XMapWindow(mainDisplay, msgWindow);
+   if (!noChoiceWindow) XMapWindow(mainDisplay, choiceWindow);
+
+   XMapWindow(mainDisplay, hRuleWindow);
+   XMapWindow(mainDisplay, vRuleWindow);
+
+   XMapWindow(mainDisplay, colorWindow);
+   XMapWindow(mainDisplay, colorDummyWindow);
+   XMapWindow(mainDisplay, vSBarWindow);
+   XMapWindow(mainDisplay, pageWindow);
+   XMapWindow(mainDisplay, pageDummyWindow);
+   XMapWindow(mainDisplay, hSBarWindow);
+   XMapWindow(mainDisplay, dummyWindow1);
+   XMapWindow(mainDisplay, dummyWindow2);
+   if (!noChatWindow) XMapWindow(mainDisplay, chatWindow);
+   if (!noStatusWindow) {
+      XMapWindow(mainDisplay, userRedrawWindow);
+      XMapWindow(mainDisplay, statusWindow);
+      for (i=0; i < MAX_STATUS_BTNS; i++) {
+         XMapWindow(mainDisplay, statusSubWindow[i]);
+      }
+   }
+   if (!noModeWindow) XMapWindow(mainDisplay, modeWindow);
+}
+
 static
 void StartSlideShow()
 {
@@ -1324,6 +1399,7 @@ void StartSlideShow()
    }
    FixPageNumbersForSlideShow();
    ClearObjCachesInAllPages();
+   HideAllWindowsForSlideShow();
    HidePopupMenusForSlideShow();
 
    RecordWBSlideShow(TRUE);
@@ -1340,6 +1416,7 @@ void EndSlideShow()
 
    RecordWBSlideShow(FALSE);
 
+   ShowAllWindowsForSlideShow();
    ShowPopupMenusForSlideShow();
    ClearObjCachesInAllPages();
    if (gstSlideShow.saved_in_hyperspace != inHyperSpace) {
