@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2003, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/ps.c,v 4.20 2002/01/05 02:48:05 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/ps.c,v 1.2 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_PS_C_
@@ -625,7 +625,7 @@ static char *psColorImageMacro[] = {
   "         { pop 1 1 iw",
   "            { pop currentfile",
   "              tgifbwpicstr readhexstring pop 0 get tgifnewcolorspot",
-  "              x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto",
+  "              newpath x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto",
   "              closepath fill",
   "              /x x 1 add def",
   "            } for",
@@ -655,7 +655,7 @@ static char *psColorImageMacro[] = {
   "       { pop 1 1 iw",
   "          { pop currentfile",
   "            tgifbwpicstr readhexstring pop 0 get tgiftranscolorspot",
-  "            { x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto",
+  "            { newpath x y moveto 1 0 rlineto 0 1 rlineto -1 0 rlineto",
   "              closepath fill",
   "            }",
   "            if",
