@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2003, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/raster.c,v 4.17 2002/01/05 02:48:05 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/raster.c,v 1.2 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_RASTER_C_
@@ -213,6 +213,7 @@
 #include "xbm/tiffepsi.xbm"
 #include "xbm/png.xbm"
 #include "xbm/jpeg.xbm"
+#include "xbm/pbm.xbm"
 #include "xbm/netlist.xbm"
 
 #include "xbm/file.xbm"
@@ -271,8 +272,6 @@
 #include "xbm/info.xbm"
 #include "xbm/dialog.xbm"
 
-Pixmap patPixmap[MAXPATTERNS+1];
-
 GC rasterGC=NULL;
 GC patGC=NULL;
 
@@ -286,6 +285,7 @@ GC revDefaultGC=NULL;
 GC revGrayGC=NULL;
 
 Pixmap choicePixmap[MAXCHOICES];
+Pixmap patPixmap[MAXPATTERNS+1];
 Pixmap *lineWidthPixmap=NULL;
 Pixmap lineTypePixmap[MAXLINETYPES];
 Pixmap lineDashPixmap[MAXDASHES];
@@ -934,6 +934,8 @@ void InitPattern()
          mainWindow, (char *)png_bits, png_width, png_height);
    whereToPrintPixmap[JPEG_FILE] = XCreateBitmapFromData(mainDisplay,
          mainWindow, (char *)jpeg_bits, jpeg_width, jpeg_height);
+   whereToPrintPixmap[PPM_FILE] = XCreateBitmapFromData(mainDisplay,
+         mainWindow, (char *)pbm_bits, pbm_width, pbm_height);
    whereToPrintPixmap[NETLIST_FILE] = XCreateBitmapFromData(mainDisplay,
          mainWindow, (char *)netlist_bits, netlist_width, netlist_height);
 
