@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.88 2003/08/16 19:38:53 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/setup.c,v 1.11 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_SETUP_C_
@@ -257,11 +257,16 @@ int	curChoiceBeforeMakeQuiescent=NOTHING;
 
 int	noMinWinSize=TRUE;
 
+int	canvasWindowOnly=FALSE;
+
+int	talkToSelfFiledesInitialized=FALSE;
 int	talkToSelfFiledes[2];
 
-static Atom	protocolAtom=(Atom)0;
-
-static int	canvasWindowOnly=FALSE;
+static Atom	wmDeleteWindowAtom=(Atom)0;
+static Atom	utf8StringAtom=(Atom)0;
+static Atom	compoundTextAtom=(Atom)0;
+static Atom	textAtom=(Atom)0;
+static Atom	stringAtom=(Atom)0;
 
 static int	baseScrollBarW=SCROLLBAR_W;
 
@@ -269,7 +274,7 @@ void RegisterWM_DELETE_WINDOW(win)
    Window win;
 {
 #ifndef NOTR4MODE
-   XSetWMProtocols(mainDisplay, win, &protocolAtom, 1);
+   XSetWMProtocols(mainDisplay, win, &wmDeleteWindowAtom, 1);
 #endif
 }
 
@@ -282,7 +287,7 @@ int IsWM_DELETE_WINDOW(pXEvent)
       if (psz == NULL) {
          /* this should not happen, but just in case */
       } else if (strcmp("WM_PROTOCOLS", psz) == 0 &&
-            pXEvent->xclient.data.l[0] == protocolAtom) {
+            pXEvent->xclient.data.l[0] == wmDeleteWindowAtom) {
          XFree((void*)psz);
          return TRUE;
       }
@@ -650,6 +655,62 @@ int TgIsCmdEvent(pXEv)
    return FALSE;
 }
 
+#ifdef ICCCM_TEST
+static
+void HandleSelectionRequest(input)
+   XEvent *input;
+{
+   static int id=0;
+   Window      requestor=input->xselectionrequest.requestor;
+   Atom        property=(Atom)0, target=(Atom)0, selection=(Atom)0;
+
+   selection = input->xselectionrequest.selection;
+   target = input->xselectionrequest.target;
+   property = input->xselectionrequest.property;
+
+   printf("\n%1d: SelectionRequest.\n", ++id);
+
+   if (property != None) {
+      char     *atom_name=NULL;
+
+      atom_name = XGetAtomName(mainDisplay, property);
+      printf("%1d: Property name is '%s'.\n", id, atom_name);
+      XFree(atom_name);
+
+      atom_name = XGetAtomName(mainDisplay, target);
+      printf("%1d: Target name is '%s'.\n", id, atom_name);
+      XFree(atom_name);
+   } else {
+      property = target;
+   }
+   if (input->xselectionrequest.owner == mainWindow) {
+      printf("%1d: owner == mainWindow!\n", id);
+   } else {
+      XEvent      sent_ev;
+
+      memset(&sent_ev, 0, sizeof(XEvent));
+
+      sent_ev.xselectionrequest.type = SelectionNotify;
+      sent_ev.xselectionrequest.display = mainDisplay;
+      sent_ev.xselectionrequest.requestor = mainWindow;
+      sent_ev.xselectionrequest.selection = selection;
+      sent_ev.xselectionrequest.time = input->xselectionrequest.time;
+      sent_ev.xselectionrequest.target = target;
+      sent_ev.xselectionrequest.property = property;
+
+      sent_ev.xselectionrequest.send_event = True;
+      sent_ev.xselectionrequest.owner = requestor;
+
+/*       if (target == utf8StringAtom || target == compoundTextAtom ||
+            target == textAtom || target == stringAtom) {
+      } else {
+         sent_ev.xselectionrequest.property = None;
+      } */
+      XSendEvent(mainDisplay,requestor,False,NoEventMask,&sent_ev);
+   }
+}
+#endif /* ICCCM_TEST */
+
 static XComposeStatus c_stat;
 
 int mainWinEventHandler(input)
@@ -678,6 +739,11 @@ int mainWinEventHandler(input)
       case XK_KP_Right: NextPage(); return INVALID;
       default: break;
       }
+   } else if (input->type == SelectionRequest) {
+#ifdef ICCCM_TEST
+      HandleSelectionRequest(input);
+#endif /* ICCCM_TEST */
+      return INVALID;
    } else if (input->type == UnmapNotify) {
       Iconify();
    } else if (input->type == MapNotify) {
@@ -717,7 +783,7 @@ int mainWinEventHandler(input)
          } else if (strcmp("WM_MOVED", c_ptr) == 0) {
             configure = TRUE;
          } else if (strcmp("WM_PROTOCOLS", c_ptr) == 0 &&
-               input->xclient.data.l[0] == protocolAtom) {
+               input->xclient.data.l[0] == wmDeleteWindowAtom) {
             XFree((void*)c_ptr);
             return QuitProc();
          } else if (curChoice == DRAWTEXT && canvasFontDoubleByte &&
@@ -1309,7 +1375,11 @@ void Setup()
       paper_size_set = TRUE;
    }
    /* do not translate -- program constants */
-   protocolAtom = XInternAtom(mainDisplay, "WM_DELETE_WINDOW", False);
+   wmDeleteWindowAtom = XInternAtom(mainDisplay, "WM_DELETE_WINDOW", False);
+   utf8StringAtom = XInternAtom(mainDisplay, "UTF8_STRING", False);
+   compoundTextAtom = XInternAtom(mainDisplay, "COMPOUND_TEXT", False);
+   textAtom = XInternAtom(mainDisplay, "TEXT", False);
+   stringAtom = XInternAtom(mainDisplay, "STRING", False);
    executeCmdByIDAtom = XInternAtom(mainDisplay, "TGIF_EXECUTE_CMD_BY_ID",
          False);
 
@@ -1416,6 +1486,12 @@ void Setup()
          UtilStrICmp(c_ptr, "false") == 0) {
       stretchableText = FALSE;
    }
+   compoundObjWithTextStretchableForPSE = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
+         "CompoundObjWithTextStretchableForPSE")) != NULL &&
+         UtilStrICmp(c_ptr, "true") == 0) {
+      compoundObjWithTextStretchableForPSE = TRUE;
+   }
    SetEditTextSizeValue(0);
    if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "EditTextSize")) != NULL) {
       int new_edit_text_size=atoi(c_ptr);
@@ -1703,6 +1779,11 @@ void Setup()
    } else if (!y_in_cmdline && y_neg_in_def) {
       sizehints.y = def_y_neg+DisplayHeight(mainDisplay,mainScreen)-mainWinH-1;
    }
+#if defined(_TANGRAM_II) || defined(_TGIF_WB2)
+   if ( cmdLineParentWindowID > 0 ) {
+      rootWindow = cmdLineParentWindowID;
+   }
+#endif /* defined(_TANGRAM_II) || defined(_TGIF_WB2) */
    if ((mainWindow=XCreateSimpleWindow(mainDisplay, rootWindow,
          sizehints.x, sizehints.y, sizehints.width, sizehints.height,
          brdrW, myBorderPixel, myBgPixel)) == 0) {
@@ -1922,6 +2003,7 @@ void Setup()
    InitMeasureTooltip();
    InitPoly();
    InitSpecial();
+   InitAttr();
    InitTalkToSelfFiledes();
 
 #ifdef MAPBEFORESELECT
