@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2003, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/shape.c,v 4.18 2002/03/06 07:23:39 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shape.c,v 1.2 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_SHAPE_C_
@@ -818,7 +818,7 @@ void GenerateShadow()
    struct ObjRec *obj_ptr;
    struct SelRec *tmp_top_sel=NULL, *tmp_bot_sel=NULL;
 
-   SelAllObj(FALSE);
+   SelAllObj(FALSE, FALSE);
 
    JustDupSelObj(&tmp_top_sel, &tmp_bot_sel);
    /*
@@ -957,7 +957,7 @@ struct AttrRec *GenerateShape()
     * Use the next two functions to set selLtX, etc. to be used
     *    in CreateGroupObj().
     */
-   SelAllObj(FALSE);
+   SelAllObj(FALSE, FALSE);
    RemoveAllSel();
 
    tmp_top_obj = topObj;
