@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/shortcut.c,v 4.93 2003/08/16 19:38:53 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/shortcut.c,v 1.5 2005/01/15 00:23:23 william Exp $
  */
 
 #define _INCLUDE_FROM_SHORTCUT_C_
@@ -153,7 +153,7 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { 'p', CNTRL_META, "BoldItalic()", 0, CMDID_BOLDITALIC },
    { 'q', CNTRL_META, "DrawPolygon()", 0, CMDID_DRAWPOLYGON },
    { 'r', CNTRL_META, "Right()", 0, CMDID_RIGHT },
-   { 's', CNTRL_META, "SaveNew()", 0, CMDID_SAVENEW },
+   { 's', CNTRL_META, "SaveNew()", 1, CMDID_SAVENEW },
    { 't', CNTRL_META, "Italic()", 0, CMDID_ITALIC },
    { 'u', CNTRL_META, "UpdateSymbols()", 0, CMDID_UPDATESYMBOLS },
    { 'v', CNTRL_META, "DrawOval()", 0, CMDID_DRAWOVAL },
@@ -435,6 +435,8 @@ static struct ShortCutRec shortCutXlateTbl[] = {
    { '\0', 0, "ResetInputMethod()", 0, CMDID_RESETINMETHOD },
    { '\0', 0, "ImportPBMFile()", 0, CMDID_IMPORTPBMFILE },
    { '\0', 0, "ImportPGMFile()", 0, CMDID_IMPORTPGMFILE },
+   { '\0', 0, "EditIndexedAttrGroupInEditor()", 0,
+               CMDID_EDITATTRGROUPINEDITOR },
    { '\0', 0, "", 0, 0 }
 };
 
