@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/types.h,v 4.66 2003/08/13 20:15:16 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/types.h,v 1.2 2005/01/15 00:23:24 william Exp $
  */
 
 #ifndef _TGIF_TYPES_H_
@@ -513,6 +513,17 @@ typedef struct WinInfoRec {
    void		*userdata;
 } * WinInfoPtr;
 
+typedef struct tagKeyOrBtnEvInfo {
+   int		type;
+   Bool		send_event;
+   Display	*display;
+   Window	window;
+   Time		time;
+   int		x, y;
+   unsigned int	keycode_or_button;
+   unsigned int	state;
+} KeyOrBtnEvInfo;
+
 typedef struct MtrxRec {
    float	m[2][2], rev_m[2][2], h_scale, v_scale;
    float	image_w, image_h, w, h, transformed_w, transformed_h;
