@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/util.c,v 4.16 2003/02/25 01:17:49 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/util.c,v 1.3 2005/01/15 00:23:24 william Exp $
  */
 
 #define _INCLUDE_FROM_UTIL_C_
@@ -429,6 +429,59 @@ int UtilCopyFile(pszFromFile, pszToFile)
    return TG_REMOTE_STATUS_OK;
 }
 
+int UtilConcatFile(pszFromFile1, pszFromFile2, pszToFile)
+   char *pszFromFile1, *pszFromFile2, *pszToFile;
+{
+   char buf[0x1000];
+   int bytes_read=0;
+   int fd1=(-1), fd2=(-1), fd3=(-1);
+
+   if ((fd1=open(pszFromFile1, O_RDONLY)) == (-1)) return TG_REMOTE_STATUS_READ;
+   if ((fd2=open(pszFromFile2, O_RDONLY)) == (-1)) {
+      close(fd1);
+      return TG_REMOTE_STATUS_READ;
+   }
+   if (UtilPathExists(pszToFile)) {
+      if ((fd3=open(pszToFile, O_WRONLY|O_TRUNC)) == (-1)) {
+         close(fd1);
+         close(fd2);
+         return TG_REMOTE_STATUS_WRITE;
+      }
+   } else {
+      if ((fd3=open(pszToFile, O_WRONLY|O_CREAT|O_TRUNC, tmpFileMode)) ==
+            (-1)) {
+         close(fd1);
+         close(fd2);
+         return TG_REMOTE_STATUS_WRITE;
+      }
+   }
+   while ((bytes_read=read(fd1, buf, sizeof(buf))) > 0) {
+      if (write(fd3, buf, bytes_read) <= 0) {
+         close(fd1);
+         close(fd2);
+         close(fd3);
+         return TG_REMOTE_STATUS_FILE;
+      }
+   }
+   close(fd1);
+   while ((bytes_read=read(fd2, buf, sizeof(buf))) > 0) {
+      if (write(fd3, buf, bytes_read) <= 0) {
+         close(fd2);
+         close(fd3);
+         return TG_REMOTE_STATUS_FILE;
+      }
+   }
+   close(fd2);
+   close(fd3);
+   if (tmpFileMode != 0 && chmod(pszToFile, tmpFileMode)) {
+      char msg[MAXSTRING<<1];
+
+      sprintf(msg, TgLoadString(STID_CANNOT_CHMOD), pszToFile, tmpFileMode);
+      MsgBox(msg, TOOL_NAME, INFO_MB);
+   }
+   return TG_REMOTE_STATUS_OK;
+}
+
 int UtilPathExists(pszPath)
    char *pszPath;
 {
