@@ -1,7 +1,7 @@
 /*
  * Author:	George Carrette, <GJC@MITECH.COM> in November, 1990.
  *
- * @(#)$Header: /u/halfmoon/home/william/src/tgif/v3/RCS/vms_comp.c,v 3.5 1998/11/05 22:51:31 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/vms_comp.c,v 1.1 2004/06/18 23:19:10 william Exp $
  */
 
 /* vms_comp routines, generally useful functions
@@ -19,6 +19,7 @@
    **  Written by George Carrette, <GJC@MITECH.COM> in November, 1990.
    **  Includes modified VMS readdir() routines.
    **  Written by Rich $alz, <rsalz@bbn.com> in August, 1990.
+   **  some additions by Rolf Niepraschk, niepraschk@ptb.de, 1997/11/24
 
 To use:
 
@@ -40,7 +41,8 @@ Contains:
  readdir  ... almost full functionality.
  telldir  ... almost full functionality.
  seekdir  ... almost full functionality.
-
+ ioctl    ... dummy, returns 0. -- RN --
+ fcntl    ... dummy, returns 0. -- RN --
 
  do_vms_wildcard ... non-unix. but put this into your MAIN program to
                      get limited wildcard processing on the command line.
@@ -60,29 +62,24 @@ Contains:
    and then conditionalize it specifically for VMS
 */
 
-#ifdef VMS
-
-#include <stdio.h>
-#include <ctype.h>
-#include <errno.h>
-#include <descrip.h>
-#include <rmsdef.h>
-#include <ssdef.h>
-#include <string.h>
 #include "vms_comp.h"
 
+#ifdef VMS
+
+#if 0                    /* RN */
 bcopy(x,y,n)
      char *x,*y;
      long n;
 {memmove(x,y,n);}
 
-rindex(p,c)
+char *rindex(p,c)
      char *p;
      int c;
 {return(strrchr(p,c));}
 
 int lstat(x,y)
 {return(stat(x,y));}
+#endif                   /* RN */
 
 fork()
 {return(1);}
@@ -113,9 +110,11 @@ char *getwd(p)
  *l2 = 0;
  return(p);}
 
+#if 0                    /* RN */
 unlink(p)
      char *p;
 {delete(p);}
+#endif                   /* RN */
 
 static vms_wild_putargs(),vms_wild_put_one(),vms_wild_put_wild();
 static struct dsc$descriptor *set_dsc();
@@ -201,7 +200,7 @@ static vms_wild_put_wild(s,pargc,pargv,pvsize)
    {rval = lib$find_file_end(&context);
     if (rval != SS$_NORMAL) exit(rval);}}
 
-globalvalue CLI$M_NOWAIT;
+/* globalvalue CLI$M_NOWAIT; -- RN */
 
 static int create_mbx();
 
@@ -219,6 +218,7 @@ struct popen_cell
  struct popen_cell *next;
  struct popen_cell *prev;};
 
+#if __VMS_VER < 70000000 /* RN */
 static struct popen_cell *popen_list = NULL;
 
 static struct popen_cell *find_popen_cell(fp)
@@ -373,6 +373,8 @@ static int create_mbx(name)
  if (retval != SS$_NORMAL) return(-1);
  return(chan);}
 
+#endif /* __VMS_VER < 70000000 */ /* RN */
+
 /*
 **  VMS readdir() routines.
 **  Written by Rich $alz, <rsalz@bbn.com> in August, 1990.
@@ -621,6 +623,20 @@ void seekdir(dd, pos)
      long	pos;
 {dd->context = pos;}
 
+int ioctl(int fildes, int request,... /* arg */)
+{
+  fprintf(stderr, "\"ioctl\" not implemented (VMS)\n");
+  return 0;
+}
+
+int fcntl (int filedes, int request , int argument)
+{
+  fprintf(stderr, "\"fcntl\" not implemented (VMS)\n");
+  return 0;
+}
+
+
+
 #ifdef	TEST
 main()
 {
