@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/wb.c,v 4.122 2003/08/15 16:09:41 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/wb.c,v 1.6 2005/01/15 00:23:24 william Exp $
  */
 
 #define _INCLUDE_FROM_WB_C_
@@ -44,7 +44,7 @@
 #include <stropts.h>
 #include <sys/types.h>
 #endif /* _HAS_STREAMS_SUPPORT */
-#include "rmcast/rmcast.h"
+#include "rmcast/src/rmcast.h"
 #endif /* _TGIF_WB2 */
 
 #include "auxtext.e"
@@ -281,7 +281,7 @@ int WBHasReadData(pn_flag, pn_retry)
 {
    /* leave *pn_retry alone */
    
-   if ((!(gstWBInfo.BlockRemoteCmdDepth <= 1)) &&  (buff_items(gstWBInfo.bd_commands) > 0) ) 
+   if ((!(gstWBInfo.BlockRemoteCmdDepth <= 1)) && (buff_items(gstWBInfo.bd_commands) > 0) ) 
    {
       /* FIXME fprintf(stderr,"gstWBInfo.BlockRemoteCmdDepth > 1 e existem dados no buffer. (WBHasReadData)\n");
       exit(1); */
@@ -330,13 +330,6 @@ int SendWBData(pszWBData, logical_clock)
    for( i = 0; i < nPackets1; i++ )
    {
       RM_sendto(gstWBInfo.MCastSock, (char*)&pack1[i], sizeof(struct SegmentationPack));
-        
-      /* FIXME: Contorna a limitacao de buffer do UDP (aguarda 0.1 segs. entre envio de pcts) */
-        
-      /*
-	  if(i%10 == 9)
-	    usleep( 100000 );
-      */
    }
    free( pack1 );
 
@@ -1767,7 +1760,7 @@ void ProcessRemoteCmd(psz_buf, buf_sz)
 #ifdef _TGIF_WB2
 static
 void PackCurrentTGWBState(p_cur_state)
-    CurState *p_cur_state;
+    CurStatus *p_cur_state;
 {
    char tmp_fname[MAXPATHLENGTH], *buf=NULL, header[MAXSTRING<<1];
    int content_sz=0, ok=TRUE, header_sz=0, num_cmds=0, cur_cmd_pos=0;
@@ -1775,7 +1768,7 @@ void PackCurrentTGWBState(p_cur_state)
    long loc_sec=0L, loc_msec=0L;
    FILE *fp=NULL;
 
-   memset(p_cur_state, 0, sizeof(CurState));
+   memset(p_cur_state, 0, sizeof(CurStatus));
    if (MkTempFile(tmp_fname, sizeof(tmp_fname), tmpDir, TOOL_NAME) == NULL) {
       fprintf(stderr, TgLoadString(STID_CANT_CREATE_NAMED_TMP_FILE), tmp_fname);
       fprintf(stderr, "\n");
@@ -1881,7 +1874,7 @@ void PackCurrentTGWBState(p_cur_state)
 
 static
 void UnpackCurrentTGWBState(p_cur_state)
-    CurState *p_cur_state;
+    CurStatus *p_cur_state;
 {
    struct StkRec *stk_ptr=NULL;
    struct ObjRec *obj_ptr=NULL, *saved_top_obj=NULL, *saved_bot_obj=NULL;
@@ -2053,15 +2046,15 @@ void HandleNewUserRequest()
    }
    if (index != (-1)) {
       int conn=0;
-      CurState cur_state;
+      CurStatus cur_state;
 
-      memset(&cur_state, 0, sizeof(CurState));
+      memset(&cur_state, 0, sizeof(CurStatus));
       sscanf(buf, "%d", &conn);
       serializingFile = TRUE;
       PackCurrentTGWBState(&cur_state);
       serializingFile = FALSE;
       if (cur_state.size != 0) {
-         RM_SendCurStatus(conn, (char*)cur_state.data, cur_state.size);
+         RM_sendCurStatus(conn, (char*)cur_state.data, cur_state.size);
          UtilFree(cur_state.data);
       }
    }
@@ -2123,7 +2116,7 @@ void *ReceivePacket( void *arg )
         }
 
         /*
-         * verifica se a mensagem nao eh dele proprio
+         * check if the message is from itself
          */
 
         
@@ -2139,8 +2132,8 @@ void *ReceivePacket( void *arg )
            continue;
         }
 
-        /* Verifica se pode processar o comando agora, ou se deve armazenar */
 #ifdef DEBUG0        
+        /* Verify if either the command may be processed right now, or if it should be stored */
         fprintf(stderr,"Process the comand now? ");
 #endif        
 
@@ -2186,6 +2179,11 @@ void *ReceivePacket( void *arg )
 void CleanUpWhiteBoard()
 {
 #ifdef _TGIF_WB2
+   char buf[60];
+   
+   sprintf(buf,"****Shutting down: PLEASE WAIT****");
+   Msg(buf);
+   
    RM_leaveGroup( gstWBInfo.MCastSock, (char*)RM_USE_CURRENT_CONFIG );
    buff_destroy(gstWBInfo.bd_commands);
 #endif /* _TGIF_WB2 */
@@ -2209,15 +2207,19 @@ void handler(int a)
 int InitWhiteBoard()
 {
 #ifdef _TGIF_WB2
-   int want_new_user_support=0;
+   int want_new_member_support=0;
    pthread_t tid=(pthread_t)0;
+   char tgwb_config_file[255];
+   char * homedir=NULL;
+   int config_ok=0;
+
 #endif /* _TGIF_WB2 */
 
    InitLocalPID(); /* initializes gszLocalPID */
 
    memset(&gstWBInfo, 0, sizeof(struct WhiteBoardRec));
 
-   gstWBInfo.BlockRemoteCmdDepth = 1; /* FIXME! deveria ser zero? */
+   gstWBInfo.BlockRemoteCmdDepth = 1; /* FIXME Should be zero? */
    gstWBInfo.pid = (long)getpid();
 
 #ifdef _TGIF_WB2
@@ -2253,7 +2255,6 @@ int InitWhiteBoard()
          CleanUpWBSockets();
          exit(-1);
       }
-      /* fim do trecho */
 
       if (MkTempFile(gstWBInfo.send_fname, sizeof(gstWBInfo.send_fname),
             tmpDir, TOOL_NAME) == NULL) {
@@ -2266,11 +2267,29 @@ int InitWhiteBoard()
                gstWBInfo.send_fname);
          exit(-1);
       }
-      /* Creation of multicast socket */
-      
-      /* sprintf(logfile, "%snome.txt", TMP_DIR); */
 
-      RM_readConfigFile("rmcast.config");
+      if ( (homedir=getenv("HOME")) != NULL ){
+        sprintf(tgwb_config_file,"%s/.tgwb/tgwb.config",homedir);
+        if (RM_readConfigFile(tgwb_config_file, 0))
+             config_ok=2; /* It means that we read $HOME/.tgwb/tgwb.config */
+      }
+      else{
+         fprintf(stderr,"TGWB Warning: Can't get environment variable 'HOME', using default values.\n");
+      }
+      if (config_ok==0 && RM_readConfigFile("/etc/tgwb.config", 0)){
+           config_ok=1; /* It means that we read /etc/tgwb.config */
+      }
+
+      switch (config_ok){
+         case 1:
+            fprintf(stderr,"Using config file: '/etc/tgwb.config'\n");
+            break;
+         case 2:
+            fprintf(stderr,"Using config file: '%s'\n",tgwb_config_file);
+            break;
+         default:
+            fprintf(stderr,"TGWB Warning:\n Config files:\n\t'%s/.tgwb/tgwb.config'\n\t'/etc/tgwb.config'\n not found.\nUsing default values.\n",homedir);
+      }
 
       /* setting defaults */
 
@@ -2279,15 +2298,15 @@ int InitWhiteBoard()
 
       RM_initialize();
 
-      RM_getOption(NEW_USER_SUPPORT, (void*)&want_new_user_support);
+      RM_getOption(NEW_MEMBER_SUPPORT, (void*)&want_new_member_support);
 
-      if (want_new_user_support)
+      if (want_new_member_support)
       {
-           CurState cur_state;
+           CurStatus cur_state;
 
-           fprintf(stderr,"Getting the current state.\n");
+           fprintf(stderr,"Getting the current status.\n");
 
-           RM_getCurState( (char*)RM_USE_CURRENT_CONFIG, RM_USE_CURRENT_CONFIG,
+           RM_getCurStatus( (char*)RM_USE_CURRENT_CONFIG, RM_USE_CURRENT_CONFIG,
                    &cur_state);
 
            if (cur_state.size != -1)
@@ -2297,9 +2316,7 @@ int InitWhiteBoard()
                deserializingFile = FALSE;
            }
       }
-      gstWBInfo.MCastSock = RM_joinGroup(
-              (char*)RM_USE_CURRENT_CONFIG /* "225.1.2.3" */,
-              RM_USE_CURRENT_CONFIG /* 5000 */ );
+      gstWBInfo.MCastSock = RM_joinGroup((char*)RM_USE_CURRENT_CONFIG, RM_USE_CURRENT_CONFIG );
 
       gstWBInfo.bd_commands = buff_init (10, WB_PACK, UNSORTED, NULL );
       
@@ -2308,7 +2325,7 @@ int InitWhiteBoard()
 */      
       if( pthread_create( &tid, NULL, ReceivePacket, NULL ) != 0 )
       {
-          fprintf( stderr, "Could create receive thread\n" );
+          fprintf( stderr, "Could not create receive thread\n" );
           exit( -1 );
       }
    }
