@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 1990-2003, William Chia-Wei Cheng.
+ * Copyright (C) 1990-2005, William Chia-Wei Cheng.
  *
  * Permission limited to the use, copy, display, distribute without
  * charging for a fee, and produce derivative works of "tgif" and
@@ -28,7 +28,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/xprtfltr.c,v 4.21 2003/08/16 19:38:53 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/xprtfltr.c,v 1.2 2005/01/15 00:23:24 william Exp $
  */
 
 #define _INCLUDE_FROM_XPRTFLTR_C_
@@ -347,12 +347,12 @@ int InitExportFilters()
 /* do not translate -- program constants */
 static char *gpszColorExportName[MAXDEFWHERETOPRINT] = {
    "Printer", "EPS", "PS", "XPM", "ASCII", "EPSI", "GIF/ISMAP", "HTML/USEMAP",
-   "PDF", "TiffEPSI", "PNG", "JPEG", "NetList"
+   "PDF", "TiffEPSI", "PNG", "JPEG", "PPM", "NetList"
 };
 
 static char *gpszBWExportName[MAXDEFWHERETOPRINT] = {
    "Printer", "EPS", "PS", "XBM", "ASCII", "EPSI", "GIF/ISMAP", "HTML/USEMAP",
-   "PDF", "TiffEPSI", "PNG", "JPEG", "NetList"
+   "PDF", "TiffEPSI", "PNG", "JPEG", "PBM", "NetList"
 };
 
 static char *gpszColorExportExt[MAXDEFWHERETOPRINT] = {
